# This file was auto-generated by Fern from our API Definition.

import typing
from .custom_model_id import CustomModelId
from .custom_model_version_id import CustomModelVersionId

CustomModel = typing.Union[CustomModelId, CustomModelVersionId]



# This file was auto-generated by Fern from our API Definition.

import typing

WebhookEventChatStatus = typing.Union[
    typing.Literal["ACTIVE", "USER_ENDED", "USER_TIMEOUT", "INACTIVITY_TIMEOUT", "MAX_DURATION_TIMEOUT", "ERROR"],
    typing.Any,
]



"""Client operations for managing EVI chats."""

import logging
from typing import Iterator

from hume.legacy._common.client_base import ClientBase
from hume.legacy._common.utilities.paging_utilities import Paging
from hume.legacy._voice.models.chats_models import (
    ChatEvent,
    ChatEventsResponse,
    ChatGroupEvent,
    ChatGroupEventsResponse,
    ChatGroupResponse,
    ChatGroupsResponse,
    ChatMessage,
    ChatResponse,
    ChatsResponse,
    VoiceChat,
    VoiceChatGroup,
)

logger = logging.getLogger(__name__)


# pylint: disable=redefined-builtin
class ChatsMixin(ClientBase):
    """Client operations for managing EVI chats."""

    def iter_chat_groups(self) -> Iterator[VoiceChatGroup]:
        """Iterate over existing EVI chat groups."""
        endpoint = self._build_endpoint("evi", "chat_groups")
        for page_number in range(self.PAGING_LIMIT):
            paging = Paging(page_size=self._page_size, page_number=page_number)
            response = self._request(endpoint, method="GET", paging=paging)
            chats_response = ChatGroupsResponse.model_validate_json(response.text)
            if len(chats_response.chat_groups_page) == 0:
                break
            for res in chats_response.chat_groups_page:
                yield self._chat_group_from_response(res)

    def get_chat_group(self, id: str) -> VoiceChatGroup:
        """Get an EVI chat group by its ID.

        Args:
            id (str): Chat group ID.
        """
        endpoint = self._build_endpoint("evi", f"chat_groups/{id}")
        response = self._request(endpoint, method="GET")
        chats_response = ChatGroupResponse.model_validate_json(response.text)
        return self._chat_group_from_response(chats_response)

    def _chat_group_from_response(self, chat_group_response: ChatGroupResponse) -> VoiceChatGroup:
        return VoiceChatGroup(
            id=chat_group_response.id,
            first_start_timestamp=chat_group_response.first_start_timestamp,
            most_recent_start_timestamp=chat_group_response.most_recent_start_timestamp,
            num_chats=chat_group_response.num_chats,
            is_active=chat_group_response.is_active,
        )

    def iter_chat_group_messages(self, id: str) -> Iterator[ChatMessage]:
        """Iterate over chat messages for a given chat group ID.

        Args:
            id (str): Chat group ID.
        """
        endpoint = self._build_endpoint("evi", f"chat_groups/{id}/events")
        for page_number in range(self.PAGING_LIMIT):
            paging = Paging(page_size=self._page_size, page_number=page_number)
            response = self._request(endpoint, method="GET", paging=paging)
            chat_group_events_response = ChatGroupEventsResponse.model_validate_json(response.text)
            if len(chat_group_events_response.events_page) == 0:
                break
            for chat_group_event in chat_group_events_response.events_page:
                yield self._chat_message_from_chat_group_event(chat_group_event)

    def _chat_message_from_chat_group_event(self, chat_group_event: ChatGroupEvent) -> ChatMessage:
        return ChatMessage(
            timestamp=chat_group_event.timestamp,
            role=chat_group_event.role,
            type=chat_group_event.type,
            message_text=chat_group_event.message_text,
            function_call=None,
            emotion_features=chat_group_event.emotion_features,
            metadata=chat_group_event.metadata,
        )

    def iter_chats(self) -> Iterator[VoiceChat]:
        """Iterate over existing EVI chats."""
        endpoint = self._build_endpoint("evi", "chats")
        for page_number in range(self.PAGING_LIMIT):
            paging = Paging(page_size=self._page_size, page_number=page_number)
            response = self._request(endpoint, method="GET", paging=paging)
            chats_response = ChatsResponse.model_validate_json(response.text)
            if len(chats_response.chats_page) == 0:
                break
            for res in chats_response.chats_page:
                yield self._chat_from_response(res)

    def get_chat(self, id: str) -> VoiceChat:
        """Get an EVI chat by its ID.

        Args:
            id (str): Chat ID.
        """
        endpoint = self._build_endpoint("evi", f"chats/{id}")
        response = self._request(endpoint, method="GET")
        chats_response = ChatResponse.model_validate_json(response.text)
        return self._chat_from_response(chats_response)

    def _chat_from_response(self, chat_response: ChatResponse) -> VoiceChat:
        return VoiceChat(
            id=chat_response.id,
            chat_group_id=chat_response.chat_group_id,
            start_timestamp=chat_response.start_timestamp,
            end_timestamp=chat_response.end_timestamp,
        )

    def iter_chat_messages(self, id: str) -> Iterator[ChatMessage]:
        """Iterate over chat messages for a given chat ID.

        Args:
            id (str): Chat ID.
        """
        endpoint = self._build_endpoint("evi", f"chats/{id}")
        for page_number in range(self.PAGING_LIMIT):
            paging = Paging(page_size=self._page_size, page_number=page_number)
            response = self._request(endpoint, method="GET", paging=paging)
            chat_events_response = ChatEventsResponse.model_validate_json(response.text)
            if len(chat_events_response.events_page) == 0:
                break
            for chat_event in chat_events_response.events_page:
                yield self._chat_message_from_chat_event(chat_event)

    def _chat_message_from_chat_event(self, chat_event: ChatEvent) -> ChatMessage:
        return ChatMessage(
            timestamp=chat_event.timestamp,
            role=chat_event.role,
            type=chat_event.type,
            message_text=chat_event.message_text,
            function_call=chat_event.function_call,
            emotion_features=chat_event.emotion_features,
            metadata=chat_event.metadata,
        )



# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import SyncClientWrapper
from .tools.client import ToolsClient
from .prompts.client import PromptsClient
from .custom_voices.client import CustomVoicesClient
from .configs.client import ConfigsClient
from .chats.client import ChatsClient
from .chat_groups.client import ChatGroupsClient
from ..core.client_wrapper import AsyncClientWrapper
from .tools.client import AsyncToolsClient
from .prompts.client import AsyncPromptsClient
from .custom_voices.client import AsyncCustomVoicesClient
from .configs.client import AsyncConfigsClient
from .chats.client import AsyncChatsClient
from .chat_groups.client import AsyncChatGroupsClient


class EmpathicVoiceClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.tools = ToolsClient(client_wrapper=self._client_wrapper)
        self.prompts = PromptsClient(client_wrapper=self._client_wrapper)
        self.custom_voices = CustomVoicesClient(client_wrapper=self._client_wrapper)
        self.configs = ConfigsClient(client_wrapper=self._client_wrapper)
        self.chats = ChatsClient(client_wrapper=self._client_wrapper)
        self.chat_groups = ChatGroupsClient(client_wrapper=self._client_wrapper)


class AsyncEmpathicVoiceClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.tools = AsyncToolsClient(client_wrapper=self._client_wrapper)
        self.prompts = AsyncPromptsClient(client_wrapper=self._client_wrapper)
        self.custom_voices = AsyncCustomVoicesClient(client_wrapper=self._client_wrapper)
        self.configs = AsyncConfigsClient(client_wrapper=self._client_wrapper)
        self.chats = AsyncChatsClient(client_wrapper=self._client_wrapper)
        self.chat_groups = AsyncChatGroupsClient(client_wrapper=self._client_wrapper)



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from .error_level import ErrorLevel
from .tool_type import ToolType
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ToolErrorMessage(UniversalBaseModel):
    """
    When provided, the output is a function call error.
    """

    code: typing.Optional[str] = pydantic.Field(default=None)
    """
    Error code. Identifies the type of error encountered.
    """

    content: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional text passed to the supplemental LLM in place of the tool call result. The LLM then uses this text to generate a response back to the user, ensuring continuity in the conversation if the tool errors.
    """

    custom_session_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Used to manage conversational state, correlate frontend and backend data, and persist conversations across EVI sessions.
    """

    error: str = pydantic.Field()
    """
    Error message from the tool call, not exposed to the LLM or user.
    """

    level: typing.Optional[ErrorLevel] = pydantic.Field(default=None)
    """
    Indicates the severity of an error; for a Tool Error message, this must be `warn` to signal an unexpected event.
    """

    tool_call_id: str = pydantic.Field()
    """
    The unique identifier for a specific tool call instance.
    
    This ID is used to track the request and response of a particular tool invocation, ensuring that the Tool Error message is linked to the appropriate tool call request. The specified `tool_call_id` must match the one received in the [Tool Call message](/reference/empathic-voice-interface-evi/chat/chat#receive.Tool%20Call%20Message.type).
    """

    tool_type: typing.Optional[ToolType] = pydantic.Field(default=None)
    """
    Type of tool called. Either `builtin` for natively implemented tools, like web search, or `function` for user-defined tools.
    """

    type: typing.Literal["tool_error"] = pydantic.Field(default="tool_error")
    """
    The type of message sent through the socket; for a Tool Error message, this must be `tool_error`.
    
    Upon receiving a [Tool Call message](/reference/empathic-voice-interface-evi/chat/chat#receive.Tool%20Call%20Message.type) and failing to invoke the function, this message is sent to notify EVI of the tool's failure.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

Bcp47Tag = typing.Union[
    typing.Literal[
        "zh",
        "da",
        "nl",
        "en",
        "en-AU",
        "en-IN",
        "en-NZ",
        "en-GB",
        "fr",
        "fr-CA",
        "de",
        "hi",
        "hi-Latn",
        "id",
        "it",
        "ja",
        "ko",
        "no",
        "pl",
        "pt",
        "pt-BR",
        "pt-PT",
        "ru",
        "es",
        "es-419",
        "sv",
        "ta",
        "tr",
        "uk",
    ],
    typing.Any,
]



"""Module init."""

from hume.legacy._measurement.stream.hume_stream_client import HumeStreamClient
from hume.legacy._measurement.stream.stream_socket import StreamSocket

__all__ = [
    "HumeStreamClient",
    "StreamSocket",
]



# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from .custom_model_prediction import CustomModelPrediction
from ....core.pydantic_utilities import IS_PYDANTIC_V2


class TlInferencePrediction(UniversalBaseModel):
    file: str = pydantic.Field()
    """
    A file path relative to the top level source URL or file.
    """

    file_type: str
    custom_models: typing.Dict[str, CustomModelPrediction]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .....core.pydantic_utilities import UniversalBaseModel
import typing
from .stream_model_predictions_language_predictions_item import StreamModelPredictionsLanguagePredictionsItem
from .....core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class StreamModelPredictionsLanguage(UniversalBaseModel):
    """
    Response for the language emotion model.
    """

    predictions: typing.Optional[typing.List[StreamModelPredictionsLanguagePredictionsItem]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .....core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from .....core.pydantic_utilities import IS_PYDANTIC_V2


class StreamLanguage(UniversalBaseModel):
    """
    Configuration for the language emotion model.
    """

    sentiment: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Configuration for sentiment predictions. If missing or null, no sentiment predictions will be generated.
    """

    toxicity: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Configuration for toxicity predictions. If missing or null, no toxicity predictions will be generated.
    """

    granularity: typing.Optional[str] = pydantic.Field(default=None)
    """
    The granularity at which to generate predictions. Values are `word`, `sentence`, `utterance`, or `passage`. To get a single prediction for the entire text of your streaming payload use `passage`. Default value is `word`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class PostedTimeoutSpecsInactivity(UniversalBaseModel):
    """
    Specifies the duration of user inactivity (in seconds) after which the EVI WebSocket connection will be automatically disconnected. Default is 600 seconds (10 minutes).

    Accepts a minimum value of 30 seconds and a maximum value of 1,800 seconds.
    """

    enabled: bool = pydantic.Field()
    """
    Boolean indicating if this timeout is enabled.
    
    If set to false, EVI will not timeout due to a specified duration of user inactivity being reached. However, the conversation will eventually disconnect after 1,800 seconds (30 minutes), which is the maximum WebSocket duration limit for EVI.
    """

    duration_secs: typing.Optional[int] = pydantic.Field(default=None)
    """
    Duration in seconds for the timeout (e.g. 600 seconds represents 10 minutes).
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



"""Abstract base class for model configurations."""

import warnings
from abc import ABC
from dataclasses import asdict, dataclass, fields
from typing import Any, Generic, TypeVar, cast

T = TypeVar("T")  # Type for subclasses of ConfigBase


@dataclass
class ConfigBase(ABC, Generic[T]):
    """Abstract base class for configurations."""

    def to_dict(self, skip_none: bool = True) -> dict[str, Any]:
        """Serialize configuration to dictionary.

        Args:
            skip_none (bool): Whether None configurations should be skipped during serialization.

        Returns:
            dict[str, Any]: Serialized configuration object.
        """
        return {k: v for k, v in asdict(self).items() if v is not None or not skip_none}

    @classmethod
    def from_dict(cls, request_dict: dict[str, Any]) -> T:
        """Deserialize configuration from request JSON.

        Args:
            request_dict (dict[str, Any]): Request JSON data.

        Returns:
            T: Deserialized configuration object.
        """
        class_fields = set(field.name for field in fields(cls))
        removal_params = []
        for param in request_dict:
            if param not in class_fields:
                removal_params.append(param)
                class_name = cls.__name__
                warnings.warn(
                    f"Got an unknown parameter `{param}` when loading `{class_name}`. "
                    "Your installed version of the Python SDK may be out of date "
                    "with the latest Hume APIs. "
                    "Run `pip install --upgrade hume` to get the latest version of the Python SDK."
                )
        for removal_param in removal_params:
            request_dict.pop(removal_param)

        return cast(T, cls(**request_dict))



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
from .return_chat_event_role import ReturnChatEventRole
from .return_chat_event_type import ReturnChatEventType
import typing
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ReturnChatEvent(UniversalBaseModel):
    """
    A description of a single event in a chat returned from the server
    """

    id: str = pydantic.Field()
    """
    Identifier for a Chat Event. Formatted as a UUID.
    """

    chat_id: str = pydantic.Field()
    """
    Identifier for the Chat this event occurred in. Formatted as a UUID.
    """

    timestamp: int = pydantic.Field()
    """
    Time at which the Chat Event occurred. Measured in seconds since the Unix epoch.
    """

    role: ReturnChatEventRole = pydantic.Field()
    """
    The role of the entity which generated the Chat Event. There are four possible values:
    
    - `USER`: The user, capable of sending user messages and interruptions.
    
    - `AGENT`: The assistant, capable of sending agent messages.
    
    - `SYSTEM`: The backend server, capable of transmitting errors.
    
    - `TOOL`: The function calling mechanism.
    """

    type: ReturnChatEventType = pydantic.Field()
    """
    Type of Chat Event. There are six possible values:
    
    - `SYSTEM_PROMPT`: Contains the system prompt for use in the session.
    
    - `USER_MESSAGE`: Contains the message sent by the user.
    
    - `USER_INTERRUPTION`: Contains an interruption made by the user while the agent is speaking.
    
    - `AGENT_MESSAGE`: Contains the assistant’s message, generated by Hume’s eLLM and supplemental LLM.
    
    - `FUNCTION_CALL`: Contains the invocation of a tool.
    
    - `FUNCTION_CALL_RESPONSE`: Contains the tool response.
    """

    message_text: typing.Optional[str] = pydantic.Field(default=None)
    """
    The text of the Chat Event. This field contains the message content for each event type listed in the `type` field.
    """

    emotion_features: typing.Optional[str] = pydantic.Field(default=None)
    """
    Stringified JSON containing the prosody model inference results.
    
    EVI uses the prosody model to measure 48 expressions related to speech and vocal characteristics. These results contain a detailed emotional and tonal analysis of the audio. Scores typically range from 0 to 1, with higher values indicating a stronger confidence level in the measured attribute.
    """

    metadata: typing.Optional[str] = pydantic.Field(default=None)
    """
    Stringified JSON with additional metadata about the chat event.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .tool_response_message import ToolResponseMessage
from .tool_error_message import ToolErrorMessage

ChatMessageToolResult = typing.Union[ToolResponseMessage, ToolErrorMessage]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .return_voice_provider import ReturnVoiceProvider
import pydantic
import typing
from .return_custom_voice import ReturnCustomVoice
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ReturnVoice(UniversalBaseModel):
    """
    A specific voice specification
    """

    provider: ReturnVoiceProvider = pydantic.Field()
    """
    The provider of the voice to use. Supported values are `HUME_AI` and `CUSTOM_VOICE`.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the specified voice.
    
    This will either be the name of a previously created Custom Voice or one of our 8 base voices: `ITO`, `KORA`, `DACHER`, `AURA`, `FINN`, `WHIMSY`, `STELLA`, or `SUNNY`.
    """

    custom_voice: typing.Optional[ReturnCustomVoice] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

ReturnLanguageModelModelResource = typing.Union[
    typing.Literal[
        "claude-3-5-sonnet-latest",
        "claude-3-5-haiku-latest",
        "claude-3-5-sonnet-20240620",
        "claude-3-5-haiku-20241022",
        "claude-3-opus-20240229",
        "claude-3-sonnet-20240229",
        "claude-3-haiku-20240307",
        "claude-2.1",
        "claude-instant-1.2",
        "gemini-1.5-pro",
        "gemini-1.5-flash",
        "gemini-1.5-pro-002",
        "gemini-1.5-flash-002",
        "gpt-4-turbo-preview",
        "gpt-3.5-turbo-0125",
        "gpt-3.5-turbo",
        "gpt-4o",
        "gpt-4o-mini",
        "gemma-7b-it",
        "llama3-8b-8192",
        "llama3-70b-8192",
        "llama-3.1-70b-versatile",
        "llama-3.1-8b-instant",
        "accounts/fireworks/models/mixtral-8x7b-instruct",
        "accounts/fireworks/models/llama-v3p1-405b-instruct",
        "accounts/fireworks/models/llama-v3p1-70b-instruct",
        "accounts/fireworks/models/llama-v3p1-8b-instruct",
        "ellm",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

ReturnLanguageModelModelProvider = typing.Union[
    typing.Literal["OPEN_AI", "CUSTOM_LANGUAGE_MODEL", "ANTHROPIC", "FIREWORKS", "GROQ", "GOOGLE"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from .posted_utterance_voice import PostedUtteranceVoice
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class PostedUtterance(UniversalBaseModel):
    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Natural language instructions describing how the synthesized speech should sound, including  but not limited to tone, intonation, pacing, and accent (e.g., 'a soft, gentle voice with a strong British  accent').
    - If a Voice is specified in the request, this description serves as acting instructions.
    - If  no Voice is specified, a new voice is generated based on this description.
    
     See our  [prompting guide](/docs/text-to-speech-tts/prompting) for tips on crafting your descriptions.
    """

    speed: typing.Optional[float] = pydantic.Field(default=None)
    """
    Speed multiplier for the synthesized speech.
    """

    text: str = pydantic.Field()
    """
    The input text to be synthesized into speech.
    """

    trailing_silence: typing.Optional[float] = pydantic.Field(default=None)
    """
    Duration of trailing silence (in seconds) to add to this utterance
    """

    voice: typing.Optional[PostedUtteranceVoice] = pydantic.Field(default=None)
    """
    The `name` or `id` associated with a **Voice** from the **Voice Library** to be used as the  speaker for this and all subsequent `utterances`, until the `voice` field is updated again.
    
     See our  [voices guide](/docs/text-to-speech-tts/voices) for more details on generating and specifying **Voices**.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .....core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from .stream_face import StreamFace
from .stream_language import StreamLanguage
from .....core.pydantic_utilities import IS_PYDANTIC_V2


class Config(UniversalBaseModel):
    """
    Configuration used to specify which models should be used and with what settings.
    """

    burst: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Configuration for the vocal burst emotion model.
    
    Note: Model configuration is not currently available in streaming.
    
    Please use the default configuration by passing an empty object `{}`.
    """

    face: typing.Optional[StreamFace] = pydantic.Field(default=None)
    """
    Configuration for the facial expression emotion model.
    
    Note: Using the `reset_stream` parameter does not have any effect on face identification. A single face identifier cache is maintained over a full session whether `reset_stream` is used or not.
    """

    facemesh: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Configuration for the facemesh emotion model.
    
    Note: Model configuration is not currently available in streaming.
    
    Please use the default configuration by passing an empty object `{}`.
    """

    language: typing.Optional[StreamLanguage] = pydantic.Field(default=None)
    """
    Configuration for the language emotion model.
    """

    prosody: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Configuration for the speech prosody emotion model.
    
    Note: Model configuration is not currently available in streaming.
    
    Please use the default configuration by passing an empty object `{}`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ChatMetadata(UniversalBaseModel):
    """
    When provided, the output is a chat metadata message.
    """

    chat_group_id: str = pydantic.Field()
    """
    ID of the Chat Group.
    
    Used to resume a Chat when passed in the [resumed_chat_group_id](/reference/empathic-voice-interface-evi/chat/chat#request.query.resumed_chat_group_id) query parameter of a subsequent connection request. This allows EVI to continue the conversation from where it left off within the Chat Group.
    
    Learn more about [supporting chat resumability](/docs/empathic-voice-interface-evi/faq#does-evi-support-chat-resumability) from the EVI FAQ.
    """

    chat_id: str = pydantic.Field()
    """
    ID of the Chat session. Allows the Chat session to be tracked and referenced.
    """

    custom_session_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Used to manage conversational state, correlate frontend and backend data, and persist conversations across EVI sessions.
    """

    request_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    ID of the initiating request.
    """

    type: typing.Literal["chat_metadata"] = pydantic.Field(default="chat_metadata")
    """
    The type of message sent through the socket; for a Chat Metadata message, this must be `chat_metadata`.
    
    The Chat Metadata message is the first message you receive after establishing a connection with EVI and contains important identifiers for the current Chat session.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .return_generation import ReturnGeneration
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ReturnTts(UniversalBaseModel):
    generations: typing.List[ReturnGeneration]
    request_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    A unique ID associated with this request for tracking and troubleshooting. Use this ID when  contacting [support](/support) for troubleshooting assistance.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .return_voice import ReturnVoice
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ReturnPagedVoices(UniversalBaseModel):
    """
    A paginated list Octave voices available for text-to-speech
    """

    page_number: typing.Optional[int] = None
    page_size: typing.Optional[int] = None
    total_pages: typing.Optional[int] = None
    voices_page: typing.Optional[typing.List[ReturnVoice]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



"""Module init."""

from importlib.metadata import version

from hume.legacy._measurement.batch import (
    BatchJob,
    BatchJobDetails,
    BatchJobState,
    BatchJobStatus,
    HumeBatchClient,
    TranscriptionConfig,
)
from hume.legacy._measurement.stream import HumeStreamClient, StreamSocket
from hume.legacy._voice import (
    HumeVoiceClient,
    LanguageModelConfig,
    MicrophoneInterface,
    VoiceChat,
    VoiceConfig,
    VoiceIdentityConfig,
    VoiceSocket,
    VoiceTool,
)
from hume.legacy.error.hume_client_exception import HumeClientException

__version__ = version("hume")

__all__ = [
    "__version__",
    "BatchJob",
    "BatchJobDetails",
    "BatchJobState",
    "BatchJobStatus",
    "HumeBatchClient",
    "HumeClientException",
    "HumeStreamClient",
    "HumeVoiceClient",
    "LanguageModelConfig",
    "MicrophoneInterface",
    "StreamSocket",
    "TranscriptionConfig",
    "VoiceChat",
    "VoiceConfig",
    "VoiceIdentityConfig",
    "VoiceSocket",
    "VoiceTool",
]



# This file was auto-generated by Fern from our API Definition.

from .types import (
    Alternative,
    Bcp47Tag,
    BoundingBox,
    BurstPrediction,
    Classification,
    CompletedEmbeddingGeneration,
    CompletedInference,
    CompletedState,
    CompletedTlInference,
    CompletedTraining,
    CustomModel,
    CustomModelId,
    CustomModelPrediction,
    CustomModelRequest,
    CustomModelVersionId,
    CustomModelsInferenceJob,
    CustomModelsTrainingJob,
    Dataset,
    DatasetId,
    DatasetVersionId,
    DescriptionsScore,
    Direction,
    EmbeddingGenerationBaseRequest,
    EmbeddingGenerationJob,
    EmotionScore,
    Error,
    EvaluationArgs,
    Face,
    FacePrediction,
    FacemeshPrediction,
    FacsScore,
    Failed,
    FailedState,
    File,
    Granularity,
    GroupedPredictionsBurstPrediction,
    GroupedPredictionsFacePrediction,
    GroupedPredictionsFacemeshPrediction,
    GroupedPredictionsLanguagePrediction,
    GroupedPredictionsNerPrediction,
    GroupedPredictionsProsodyPrediction,
    InProgress,
    InProgressState,
    InferenceBaseRequest,
    InferenceJob,
    InferencePrediction,
    InferenceRequest,
    InferenceResults,
    InferenceSourcePredictResult,
    JobEmbeddingGeneration,
    JobId,
    JobInference,
    JobTlInference,
    JobTraining,
    Language,
    LanguagePrediction,
    Models,
    ModelsPredictions,
    Ner,
    NerPrediction,
    Null,
    PositionInterval,
    PredictionsOptionalNullBurstPrediction,
    PredictionsOptionalNullFacePrediction,
    PredictionsOptionalNullFacemeshPrediction,
    PredictionsOptionalTranscriptionMetadataLanguagePrediction,
    PredictionsOptionalTranscriptionMetadataNerPrediction,
    PredictionsOptionalTranscriptionMetadataProsodyPrediction,
    Prosody,
    ProsodyPrediction,
    Queued,
    QueuedState,
    RegistryFileDetail,
    Regression,
    SentimentScore,
    SortBy,
    Source,
    SourceFile,
    SourceTextSource,
    SourceUrl,
    StateEmbeddingGeneration,
    StateEmbeddingGenerationCompletedEmbeddingGeneration,
    StateEmbeddingGenerationFailed,
    StateEmbeddingGenerationInProgress,
    StateEmbeddingGenerationQueued,
    StateInference,
    StateTlInference,
    StateTlInferenceCompletedTlInference,
    StateTlInferenceFailed,
    StateTlInferenceInProgress,
    StateTlInferenceQueued,
    StateTraining,
    StateTrainingCompletedTraining,
    StateTrainingFailed,
    StateTrainingInProgress,
    StateTrainingQueued,
    Status,
    Tag,
    Target,
    Task,
    TaskClassification,
    TaskRegression,
    TextSource,
    TimeInterval,
    TlInferenceBaseRequest,
    TlInferencePrediction,
    TlInferenceResults,
    TlInferenceSourcePredictResult,
    ToxicityScore,
    TrainingBaseRequest,
    TrainingCustomModel,
    Transcription,
    TranscriptionMetadata,
    Type,
    Unconfigurable,
    UnionJob,
    UnionPredictResult,
    Url,
    ValidationArgs,
    When,
    Window,
)

__all__ = [
    "Alternative",
    "Bcp47Tag",
    "BoundingBox",
    "BurstPrediction",
    "Classification",
    "CompletedEmbeddingGeneration",
    "CompletedInference",
    "CompletedState",
    "CompletedTlInference",
    "CompletedTraining",
    "CustomModel",
    "CustomModelId",
    "CustomModelPrediction",
    "CustomModelRequest",
    "CustomModelVersionId",
    "CustomModelsInferenceJob",
    "CustomModelsTrainingJob",
    "Dataset",
    "DatasetId",
    "DatasetVersionId",
    "DescriptionsScore",
    "Direction",
    "EmbeddingGenerationBaseRequest",
    "EmbeddingGenerationJob",
    "EmotionScore",
    "Error",
    "EvaluationArgs",
    "Face",
    "FacePrediction",
    "FacemeshPrediction",
    "FacsScore",
    "Failed",
    "FailedState",
    "File",
    "Granularity",
    "GroupedPredictionsBurstPrediction",
    "GroupedPredictionsFacePrediction",
    "GroupedPredictionsFacemeshPrediction",
    "GroupedPredictionsLanguagePrediction",
    "GroupedPredictionsNerPrediction",
    "GroupedPredictionsProsodyPrediction",
    "InProgress",
    "InProgressState",
    "InferenceBaseRequest",
    "InferenceJob",
    "InferencePrediction",
    "InferenceRequest",
    "InferenceResults",
    "InferenceSourcePredictResult",
    "JobEmbeddingGeneration",
    "JobId",
    "JobInference",
    "JobTlInference",
    "JobTraining",
    "Language",
    "LanguagePrediction",
    "Models",
    "ModelsPredictions",
    "Ner",
    "NerPrediction",
    "Null",
    "PositionInterval",
    "PredictionsOptionalNullBurstPrediction",
    "PredictionsOptionalNullFacePrediction",
    "PredictionsOptionalNullFacemeshPrediction",
    "PredictionsOptionalTranscriptionMetadataLanguagePrediction",
    "PredictionsOptionalTranscriptionMetadataNerPrediction",
    "PredictionsOptionalTranscriptionMetadataProsodyPrediction",
    "Prosody",
    "ProsodyPrediction",
    "Queued",
    "QueuedState",
    "RegistryFileDetail",
    "Regression",
    "SentimentScore",
    "SortBy",
    "Source",
    "SourceFile",
    "SourceTextSource",
    "SourceUrl",
    "StateEmbeddingGeneration",
    "StateEmbeddingGenerationCompletedEmbeddingGeneration",
    "StateEmbeddingGenerationFailed",
    "StateEmbeddingGenerationInProgress",
    "StateEmbeddingGenerationQueued",
    "StateInference",
    "StateTlInference",
    "StateTlInferenceCompletedTlInference",
    "StateTlInferenceFailed",
    "StateTlInferenceInProgress",
    "StateTlInferenceQueued",
    "StateTraining",
    "StateTrainingCompletedTraining",
    "StateTrainingFailed",
    "StateTrainingInProgress",
    "StateTrainingQueued",
    "Status",
    "Tag",
    "Target",
    "Task",
    "TaskClassification",
    "TaskRegression",
    "TextSource",
    "TimeInterval",
    "TlInferenceBaseRequest",
    "TlInferencePrediction",
    "TlInferenceResults",
    "TlInferenceSourcePredictResult",
    "ToxicityScore",
    "TrainingBaseRequest",
    "TrainingCustomModel",
    "Transcription",
    "TranscriptionMetadata",
    "Type",
    "Unconfigurable",
    "UnionJob",
    "UnionPredictResult",
    "Url",
    "ValidationArgs",
    "When",
    "Window",
]



from __future__ import annotations

import logging
import urllib.parse
from contextlib import asynccontextmanager
from typing import Any, AsyncIterator, ClassVar

import websockets
import websockets.client

from hume.legacy._common.client_base import ClientBase
from hume.legacy._common.protocol import Protocol
from hume.legacy._voice.voice_socket import VoiceSocket
from hume.legacy.error.hume_client_exception import HumeClientException

logger = logging.getLogger(__name__)


class ChatMixin(ClientBase):
    """Client operations for EVI WebSocket connections."""

    DEFAULT_MAX_PAYLOAD_SIZE_BYTES: ClassVar[int] = 2**24

    @asynccontextmanager
    async def connect(
        self,
        config_id: str | None = None,
        chat_group_id: str | None = None,
    ) -> AsyncIterator[VoiceSocket]:
        """Connect to the EVI API.

        Args:
            config_id (str | None): Config ID.
            chat_group_id (str | None): Chat group ID.
        """
        uri_base = self._build_endpoint("evi", "chat", Protocol.WS)

        if config_id is not None and chat_group_id is not None:
            raise HumeClientException(
                "If resuming from a chat_group_id you must not provide a config_id. "
                "The original config for the chat group will be used automatically."
            )

        params: dict[str, Any] = {}
        if config_id is not None:
            params["config_id"] = config_id
        if chat_group_id is not None:
            params["resumed_chat_group_id"] = chat_group_id

        encoded_params = urllib.parse.urlencode(params)
        uri = f"{uri_base}?{encoded_params}"

        logger.info("Connecting to EVI API at %s", uri)

        max_size = self.DEFAULT_MAX_PAYLOAD_SIZE_BYTES
        try:
            # pylint: disable=no-member
            async with websockets.connect(  # type: ignore[attr-defined]
                uri,
                extra_headers=self._get_client_headers(),
                close_timeout=self._close_timeout,
                open_timeout=self._open_timeout,
                max_size=max_size,
            ) as protocol:
                yield VoiceSocket(protocol)
        except websockets.exceptions.InvalidStatusCode as exc:
            status_code: int = exc.status_code
            if status_code == 401:  # Unauthorized
                message = "HumeVoiceClient initialized with invalid API key."
                raise HumeClientException(message) from exc
            raise HumeClientException("Unexpected error when creating EVI API connection") from exc



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class Snippet(UniversalBaseModel):
    audio: str = pydantic.Field()
    """
    The segmented audio output in the requested format, encoded as a base64 string.
    """

    generation_id: str = pydantic.Field()
    """
    The generation ID this snippet corresponds to.
    """

    id: str = pydantic.Field()
    """
    A unique ID associated with this **Snippet**.
    """

    text: str = pydantic.Field()
    """
    The text for this **Snippet**.
    """

    utterance_index: typing.Optional[int] = pydantic.Field(default=None)
    """
    The index of the utterance in the request this snippet corresponds to.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



from hume.expression_measurement.batch.client_with_utils import AsyncBatchClientWithUtils, BatchClientWithUtils
from .client import AsyncExpressionMeasurementClient, ExpressionMeasurementClient
from .stream.socket_client import AsyncStreamClientWithWebsocket


class ExpressionMeasurementClientWithWebsocket(ExpressionMeasurementClient):
    def __init__(self, *, client_wrapper):
        super().__init__(client_wrapper=client_wrapper)
        self.batch = BatchClientWithUtils(client_wrapper=client_wrapper)
    
    @property
    def stream(self) -> None:
        raise NotImplementedError("The websocket at `.stream` is only available on the `AsyncHumeClient`, not this synchronous client (`HumeClient`).")

class AsyncExpressionMeasurementClientWithWebsocket(AsyncExpressionMeasurementClient):
    def __init__(self, *, client_wrapper):
        super().__init__(client_wrapper=client_wrapper)
        self.batch = AsyncBatchClientWithUtils(client_wrapper=client_wrapper)
        self.stream = AsyncStreamClientWithWebsocket(client_wrapper=client_wrapper)



"""Configuration for the speech prosody model."""

from __future__ import annotations

from dataclasses import dataclass

from hume.legacy.models import ModelType
from hume.legacy.models.config.model_config_base import ModelConfigBase


@dataclass
class ProsodyConfig(ModelConfigBase):
    """Configuration for the speech prosody model.

    Args:
        granularity (str | None): The granularity at which to generate predictions.
            Accepted values are `word`, `sentence`, `utterance`, or `conversational_turn`.
            The default is `utterance`.
            `utterance` corresponds to a natural pause or break in conversation
            `conversational_turn` corresponds to a change in speaker.
            This configuration is only available for the batch API.
        identify_speakers (bool | None): Whether to return identifiers for speakers over time. If true,
            unique identifiers will be assigned to spoken words to differentiate different speakers. If false,
            all speakers will be tagged with an "unknown" ID.
            This configuration is only available for the batch API.
        window (dict[str, float] | None): Sliding window used to chunk audio.
            This dictionary input takes two entries: `length` and `step` representing
            the width of the window in seconds and the step size in seconds.
            This configuration is only available for the batch API.
    """

    identify_speakers: bool | None = None
    granularity: str | None = None
    window: dict[str, float] | None = None

    @classmethod
    def get_model_type(cls) -> ModelType:
        """Get the configuration model type.

        Returns:
            ModelType: Model type.
        """
        return ModelType.PROSODY



# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from .unconfigurable import Unconfigurable
from ....core.pydantic_utilities import IS_PYDANTIC_V2


class Face(UniversalBaseModel):
    """
    The Facial Emotional Expression model analyzes human facial expressions in images and videos. Results will be provided per frame for video files.

    Recommended input file types: `.png`, `.jpeg`, `.mp4`
    """

    fps_pred: typing.Optional[float] = pydantic.Field(default=None)
    """
    Number of frames per second to process. Other frames will be omitted from the response. Set to `0` to process every frame.
    """

    prob_threshold: typing.Optional[float] = pydantic.Field(default=None)
    """
    Face detection probability threshold. Faces detected with a probability less than this threshold will be omitted from the response.
    """

    identify_faces: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to return identifiers for faces across frames. If `true`, unique identifiers will be assigned to face bounding boxes to differentiate different faces. If `false`, all faces will be tagged with an `unknown` ID.
    """

    min_face_size: typing.Optional[int] = pydantic.Field(default=None)
    """
    Minimum bounding box side length in pixels to treat as a face. Faces detected with a bounding box side length in pixels less than this threshold will be omitted from the response.
    """

    facs: typing.Optional[Unconfigurable] = None
    descriptions: typing.Optional[Unconfigurable] = None
    save_faces: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to extract and save the detected faces in the artifacts zip created by each job.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class PositionInterval(UniversalBaseModel):
    """
    Position of a segment of text within a larger document, measured in characters. Uses zero-based indexing. The beginning index is inclusive and the end index is exclusive.
    """

    begin: int = pydantic.Field()
    """
    The index of the first character in the text segment, inclusive.
    """

    end: int = pydantic.Field()
    """
    The index of the last character in the text segment, exclusive.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .posted_event_message_spec import PostedEventMessageSpec
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class PostedEventMessageSpecs(UniversalBaseModel):
    """
    Collection of event messages returned by the server.

    Event messages are sent by the server when specific events occur during a chat session. These messages are used to configure behaviors for EVI, such as controlling how EVI starts a new conversation.
    """

    on_new_chat: typing.Optional[PostedEventMessageSpec] = pydantic.Field(default=None)
    """
    Specifies the initial message EVI provides when a new chat is started, such as a greeting or welcome message.
    """

    on_inactivity_timeout: typing.Optional[PostedEventMessageSpec] = pydantic.Field(default=None)
    """
    Specifies the message EVI provides when the chat is about to be disconnected due to a user inactivity timeout, such as a message mentioning a lack of user input for a period of time.
    
    Enabling an inactivity message allows developers to use this message event for "checking in" with the user if they are not responding to see if they are still active.
    
    If the user does not respond in the number of seconds specified in the `inactivity_timeout` field, then EVI will say the message and the user has 15 seconds to respond. If they respond in time, the conversation will continue; if not, the conversation will end.
    
    However, if the inactivity message is not enabled, then reaching the inactivity timeout will immediately end the connection.
    """

    on_max_duration_timeout: typing.Optional[PostedEventMessageSpec] = pydantic.Field(default=None)
    """
    Specifies the message EVI provides when the chat is disconnected due to reaching the maximum chat duration, such as a message mentioning the time limit for the chat has been reached.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .types import (
    AssistantEnd,
    AssistantInput,
    AssistantMessage,
    AudioConfiguration,
    AudioInput,
    AudioOutput,
    BuiltInTool,
    BuiltinToolConfig,
    ChatMessage,
    ChatMessageToolResult,
    ChatMetadata,
    Context,
    ContextType,
    EmotionScores,
    Encoding,
    ErrorLevel,
    ErrorResponse,
    FunctionCallResponseInput,
    HttpValidationError,
    Inference,
    JsonMessage,
    MillisecondInterval,
    PauseAssistantMessage,
    PostedBuiltinTool,
    PostedBuiltinToolName,
    PostedConfigPromptSpec,
    PostedCustomVoice,
    PostedCustomVoiceBaseVoice,
    PostedCustomVoiceParameters,
    PostedEllmModel,
    PostedEventMessageSpec,
    PostedEventMessageSpecs,
    PostedLanguageModel,
    PostedLanguageModelModelProvider,
    PostedLanguageModelModelResource,
    PostedPromptSpec,
    PostedTimeoutSpec,
    PostedTimeoutSpecs,
    PostedTimeoutSpecsInactivity,
    PostedTimeoutSpecsMaxDuration,
    PostedUserDefinedToolSpec,
    PostedVoice,
    PostedVoiceProvider,
    PostedWebhookEventType,
    PostedWebhookSpec,
    ProsodyInference,
    ResumeAssistantMessage,
    ReturnBuiltinTool,
    ReturnBuiltinToolToolType,
    ReturnChat,
    ReturnChatAudioReconstruction,
    ReturnChatAudioReconstructionStatus,
    ReturnChatEvent,
    ReturnChatEventRole,
    ReturnChatEventType,
    ReturnChatGroup,
    ReturnChatGroupPagedAudioReconstructions,
    ReturnChatGroupPagedAudioReconstructionsPaginationDirection,
    ReturnChatGroupPagedChats,
    ReturnChatGroupPagedChatsPaginationDirection,
    ReturnChatGroupPagedEvents,
    ReturnChatGroupPagedEventsPaginationDirection,
    ReturnChatPagedEvents,
    ReturnChatPagedEventsPaginationDirection,
    ReturnChatPagedEventsStatus,
    ReturnChatStatus,
    ReturnConfig,
    ReturnConfigSpec,
    ReturnCustomVoice,
    ReturnCustomVoiceBaseVoice,
    ReturnCustomVoiceParameters,
    ReturnEllmModel,
    ReturnEventMessageSpec,
    ReturnEventMessageSpecs,
    ReturnLanguageModel,
    ReturnLanguageModelModelProvider,
    ReturnLanguageModelModelResource,
    ReturnPagedChatGroups,
    ReturnPagedChatGroupsPaginationDirection,
    ReturnPagedChats,
    ReturnPagedChatsPaginationDirection,
    ReturnPagedConfigs,
    ReturnPagedCustomVoices,
    ReturnPagedPrompts,
    ReturnPagedUserDefinedTools,
    ReturnPrompt,
    ReturnPromptVersionType,
    ReturnTimeoutSpec,
    ReturnTimeoutSpecs,
    ReturnUserDefinedTool,
    ReturnUserDefinedToolToolType,
    ReturnUserDefinedToolVersionType,
    ReturnVoice,
    ReturnVoiceProvider,
    ReturnWebhookEventType,
    ReturnWebhookSpec,
    Role,
    SessionSettings,
    SessionSettingsVariablesValue,
    TextInput,
    Tool,
    ToolCallMessage,
    ToolErrorMessage,
    ToolResponseMessage,
    ToolType,
    TtsInput,
    UserInput,
    UserInterruption,
    UserMessage,
    ValidationError,
    ValidationErrorLocItem,
    WebSocketError,
    WebhookEvent,
    WebhookEventBase,
    WebhookEventChatEnded,
    WebhookEventChatStartType,
    WebhookEventChatStarted,
    WebhookEventChatStatus,
)
from .errors import BadRequestError
from . import chat, chat_groups, chats, configs, custom_voices, prompts, tools
from .chat import PublishEvent, SubscribeEvent

__all__ = [
    "AssistantEnd",
    "AssistantInput",
    "AssistantMessage",
    "AudioConfiguration",
    "AudioInput",
    "AudioOutput",
    "BadRequestError",
    "BuiltInTool",
    "BuiltinToolConfig",
    "ChatMessage",
    "ChatMessageToolResult",
    "ChatMetadata",
    "Context",
    "ContextType",
    "EmotionScores",
    "Encoding",
    "ErrorLevel",
    "ErrorResponse",
    "FunctionCallResponseInput",
    "HttpValidationError",
    "Inference",
    "JsonMessage",
    "MillisecondInterval",
    "PauseAssistantMessage",
    "PostedBuiltinTool",
    "PostedBuiltinToolName",
    "PostedConfigPromptSpec",
    "PostedCustomVoice",
    "PostedCustomVoiceBaseVoice",
    "PostedCustomVoiceParameters",
    "PostedEllmModel",
    "PostedEventMessageSpec",
    "PostedEventMessageSpecs",
    "PostedLanguageModel",
    "PostedLanguageModelModelProvider",
    "PostedLanguageModelModelResource",
    "PostedPromptSpec",
    "PostedTimeoutSpec",
    "PostedTimeoutSpecs",
    "PostedTimeoutSpecsInactivity",
    "PostedTimeoutSpecsMaxDuration",
    "PostedUserDefinedToolSpec",
    "PostedVoice",
    "PostedVoiceProvider",
    "PostedWebhookEventType",
    "PostedWebhookSpec",
    "ProsodyInference",
    "PublishEvent",
    "ResumeAssistantMessage",
    "ReturnBuiltinTool",
    "ReturnBuiltinToolToolType",
    "ReturnChat",
    "ReturnChatAudioReconstruction",
    "ReturnChatAudioReconstructionStatus",
    "ReturnChatEvent",
    "ReturnChatEventRole",
    "ReturnChatEventType",
    "ReturnChatGroup",
    "ReturnChatGroupPagedAudioReconstructions",
    "ReturnChatGroupPagedAudioReconstructionsPaginationDirection",
    "ReturnChatGroupPagedChats",
    "ReturnChatGroupPagedChatsPaginationDirection",
    "ReturnChatGroupPagedEvents",
    "ReturnChatGroupPagedEventsPaginationDirection",
    "ReturnChatPagedEvents",
    "ReturnChatPagedEventsPaginationDirection",
    "ReturnChatPagedEventsStatus",
    "ReturnChatStatus",
    "ReturnConfig",
    "ReturnConfigSpec",
    "ReturnCustomVoice",
    "ReturnCustomVoiceBaseVoice",
    "ReturnCustomVoiceParameters",
    "ReturnEllmModel",
    "ReturnEventMessageSpec",
    "ReturnEventMessageSpecs",
    "ReturnLanguageModel",
    "ReturnLanguageModelModelProvider",
    "ReturnLanguageModelModelResource",
    "ReturnPagedChatGroups",
    "ReturnPagedChatGroupsPaginationDirection",
    "ReturnPagedChats",
    "ReturnPagedChatsPaginationDirection",
    "ReturnPagedConfigs",
    "ReturnPagedCustomVoices",
    "ReturnPagedPrompts",
    "ReturnPagedUserDefinedTools",
    "ReturnPrompt",
    "ReturnPromptVersionType",
    "ReturnTimeoutSpec",
    "ReturnTimeoutSpecs",
    "ReturnUserDefinedTool",
    "ReturnUserDefinedToolToolType",
    "ReturnUserDefinedToolVersionType",
    "ReturnVoice",
    "ReturnVoiceProvider",
    "ReturnWebhookEventType",
    "ReturnWebhookSpec",
    "Role",
    "SessionSettings",
    "SessionSettingsVariablesValue",
    "SubscribeEvent",
    "TextInput",
    "Tool",
    "ToolCallMessage",
    "ToolErrorMessage",
    "ToolResponseMessage",
    "ToolType",
    "TtsInput",
    "UserInput",
    "UserInterruption",
    "UserMessage",
    "ValidationError",
    "ValidationErrorLocItem",
    "WebSocketError",
    "WebhookEvent",
    "WebhookEventBase",
    "WebhookEventChatEnded",
    "WebhookEventChatStartType",
    "WebhookEventChatStarted",
    "WebhookEventChatStatus",
    "chat",
    "chat_groups",
    "chats",
    "configs",
    "custom_voices",
    "prompts",
    "tools",
]



# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2


class Ner(UniversalBaseModel):
    """
    The NER (Named-entity Recognition) model identifies real-world objects and concepts in passages of text. This also supports audio and video files by transcribing and then directly analyzing the transcribed text.

    Recommended input filetypes: `.txt`, `.mp3`, `.wav`, `.mp4`
    """

    identify_speakers: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to return identifiers for speakers over time. If `true`, unique identifiers will be assigned to spoken words to differentiate different speakers. If `false`, all speakers will be tagged with an `unknown` ID.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
import typing
from .null import Null
from .grouped_predictions_facemesh_prediction import GroupedPredictionsFacemeshPrediction
from ....core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class PredictionsOptionalNullFacemeshPrediction(UniversalBaseModel):
    metadata: typing.Optional[Null] = None
    grouped_predictions: typing.List[GroupedPredictionsFacemeshPrediction]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
import typing
from .models import Models
from .transcription import Transcription
import pydantic
from .file import File
from ....core.pydantic_utilities import IS_PYDANTIC_V2


class InferenceRequest(UniversalBaseModel):
    models: typing.Optional[Models] = None
    transcription: typing.Optional[Transcription] = None
    urls: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    URLs to the media files to be processed. Each must be a valid public URL to a media file (see recommended input filetypes) or an archive (`.zip`, `.tar.gz`, `.tar.bz2`, `.tar.xz`) of media files.
    
    If you wish to supply more than 100 URLs, consider providing them as an archive (`.zip`, `.tar.gz`, `.tar.bz2`, `.tar.xz`).
    """

    text: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Text to supply directly to our language and NER models.
    """

    callback_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    If provided, a `POST` request will be made to the URL with the generated predictions on completion or the error message on failure.
    """

    notify: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to send an email notification to the user upon job completion/failure.
    """

    files: typing.List[File]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
from .audio_encoding import AudioEncoding
import typing
from .snippet import Snippet
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ReturnGeneration(UniversalBaseModel):
    audio: str = pydantic.Field()
    """
    The generated audio output in the requested format, encoded as a base64 string.
    """

    duration: float = pydantic.Field()
    """
    Duration of the generated audio in seconds.
    """

    encoding: AudioEncoding
    file_size: int = pydantic.Field()
    """
    Size of the generated audio in bytes.
    """

    generation_id: str = pydantic.Field()
    """
    A unique ID associated with this TTS generation that can be used as context for generating consistent speech style and prosody across multiple requests.
    """

    snippets: typing.List[typing.List[Snippet]] = pydantic.Field()
    """
    A list of speech segments, each containing a portion of the original text optimized for  natural speech delivery. These segments represent the input text divided into more natural-sounding units.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
import typing
from .bcp_47_tag import Bcp47Tag
import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2


class Transcription(UniversalBaseModel):
    """
    Transcription-related configuration options.

    To disable transcription, explicitly set this field to `null`.
    """

    language: typing.Optional[Bcp47Tag] = pydantic.Field(default=None)
    """
    By default, we use an automated language detection method for our Speech Prosody, Language, and NER models. However, if you know what language is being spoken in your media samples, you can specify it via its BCP-47 tag and potentially obtain more accurate results.
    
    You can specify any of the following languages:
    - Chinese: `zh`
    - Danish: `da`
    - Dutch: `nl`
    - English: `en`
    - English (Australia): `en-AU`
    - English (India): `en-IN`
    - English (New Zealand): `en-NZ`
    - English (United Kingdom): `en-GB`
    - French: `fr`
    - French (Canada): `fr-CA`
    - German: `de`
    - Hindi: `hi`
    - Hindi (Roman Script): `hi-Latn`
    - Indonesian: `id`
    - Italian: `it`
    - Japanese: `ja`
    - Korean: `ko`
    - Norwegian: `no`
    - Polish: `pl`
    - Portuguese: `pt`
    - Portuguese (Brazil): `pt-BR`
    - Portuguese (Portugal): `pt-PT`
    - Russian: `ru`
    - Spanish: `es`
    - Spanish (Latin America): `es-419`
    - Swedish: `sv`
    - Tamil: `ta`
    - Turkish: `tr`
    - Ukrainian: `uk`
    """

    identify_speakers: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to return identifiers for speakers over time. If `true`, unique identifiers will be assigned to spoken words to differentiate different speakers. If `false`, all speakers will be tagged with an `unknown` ID.
    """

    confidence_threshold: typing.Optional[float] = pydantic.Field(default=None)
    """
    Transcript confidence threshold. Transcripts generated with a confidence less than this threshold will be considered invalid and not used as an input for model inference.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .audio_encoding import AudioEncoding
from .audio_format_type import AudioFormatType
from .error_response import ErrorResponse
from .format import Format
from .format_mp_3 import FormatMp3
from .format_pcm import FormatPcm
from .format_wav import FormatWav
from .http_validation_error import HttpValidationError
from .posted_context import PostedContext
from .posted_context_with_generation_id import PostedContextWithGenerationId
from .posted_context_with_utterances import PostedContextWithUtterances
from .posted_tts import PostedTts
from .posted_utterance import PostedUtterance
from .posted_utterance_voice import PostedUtteranceVoice
from .posted_utterance_voice_with_id import PostedUtteranceVoiceWithId
from .posted_utterance_voice_with_name import PostedUtteranceVoiceWithName
from .return_generation import ReturnGeneration
from .return_paged_voices import ReturnPagedVoices
from .return_tts import ReturnTts
from .return_voice import ReturnVoice
from .snippet import Snippet
from .snippet_audio_chunk import SnippetAudioChunk
from .validation_error import ValidationError
from .validation_error_loc_item import ValidationErrorLocItem
from .voice_provider import VoiceProvider

__all__ = [
    "AudioEncoding",
    "AudioFormatType",
    "ErrorResponse",
    "Format",
    "FormatMp3",
    "FormatPcm",
    "FormatWav",
    "HttpValidationError",
    "PostedContext",
    "PostedContextWithGenerationId",
    "PostedContextWithUtterances",
    "PostedTts",
    "PostedUtterance",
    "PostedUtteranceVoice",
    "PostedUtteranceVoiceWithId",
    "PostedUtteranceVoiceWithName",
    "ReturnGeneration",
    "ReturnPagedVoices",
    "ReturnTts",
    "ReturnVoice",
    "Snippet",
    "SnippetAudioChunk",
    "ValidationError",
    "ValidationErrorLocItem",
    "VoiceProvider",
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .dataset_id import DatasetId
from .dataset_version_id import DatasetVersionId

Dataset = typing.Union[DatasetId, DatasetVersionId]
